% Construct and save the PPI diffusion kernel
% Fantine Mordelet, 2012

% File containing the set of interactions from HPRD
% Each row contains an interaction, with two tab-separated gene IDs
interaction_filename = 'hprd_int_network_geneid.txt';

% File where the gene IDs of the genes in the PPI kernel matrix is written
geneID_filename = '9670GeneId.txt';

% File where the diffusion kernel is written
kernel_filename = 'PPIdiffusion.mat';



% Read interactions
PPI=dlmread(interaction_filename);

% Extract the list of genes with at least one interaction, and give them a
% new index (the output PPI kernel)
[hprdGenes b c]=unique(PPI(:));
dlmwrite(geneID_filename,hprdGenes,'delimiter','\t','precision','%.0f');

% Number of genes
Ngenes=length(hprdGenes);
% Save some memory
clear PPI hprdGenes b

%% Compute PPI diffusion kernel

% Recreate the matrix of interactions with new gene indices
PPIindex=reshape(c, length(c)/2,2);
clear c
PPIindex=[PPIindex , ones(size(PPIindex,1),1)];

% Add a zero self interaction, so as to make the Laplacian matric the right
% size
PPIindex=[PPIindex; [Ngenes Ngenes 0]];

% Adjacency matrix
Kernel = spconvert(PPIindex);
clear PPIindex Ngenes

% Symmetrize
Kernel=Kernel+triu(Kernel,1)'+tril(Kernel,-1)';

% Compute Laplacian
Kernel = diag(sum(Kernel))-Kernel;

% Normalize Laplacian to unit diagonal
Kernel = Kernel ./ (sqrt(diag(Kernel))*sqrt(diag(Kernel))' + 0.00000001);

% Compute diffusion of Laplacian (this may take a few minutes)
Kernel = expm(-Kernel);

% Normalize kernel to unit diagonal
Kernel = Kernel ./ (sqrt(diag(Kernel))*sqrt(diag(Kernel))' + 0.00000001);

% Reduce to single precision float to save space
Kernel = single(Kernel);

% Save Kernel to file
eval(['save ',kernel_filename,' Kernel'])

% Sanity check: check symmetry
issym=@(x) all(all(tril(x)==triu(x).'));
issym(Kernel) % should be 1

clear Kernel