function runProDiGe1LOO(varargin)

% Runs a leave-one-out cross validation to assess the performance of
% ProDiGe1 for every disease in the training set with more than 2 known 
% causal genes.
%
% ADDITIONAL ARGUMENTS
% - resultpathInit : the name of the path in which the results should be
%                    saved
% - C : the value of the regularization parameter of the SVM
%       (default : 1)
%
% EXAMPLE:
% runProDiGe1LOO
% runProDiGe1LOO('resultPathInit','./res/', 'C',10)

% defaut behaviour (arguments that can be set up in varargin)
resultpathInit='./';
C=1;
NbScore=30;

if ~isdeployed()
    addpath(genpath('../src/'))
end

% Parse optional arguments
l=1;
while (l<length(varargin))
    varargin{l} = varargin{l+1};
    l = l+2;
end

assoc=dlmread('../data/newHprd/associations.txt');
disorderID_list = unique(assoc(:,1));
Ndisorder=length(disorderID_list);

method = fmethod('baggingSVM', 'NbScore', NbScore, 'kernelType', 'precomputed','C',C);

Data = initialize('../data/newHprd/PPIdiffusion.mat',1,method,...
    'normalizeFeatures',0, 'fileType', 'mat');
clear method;

NbPos=NaN(Ndisorder,1);
for j=1:Ndisorder
    diseaseName=disorderID_list(j);
    NbPos(j)=length(assoc(assoc(:,1)==diseaseName,2));
end
ind = find(NbPos >= 2);

for j=1:length(ind)
    diseaseName=disorderID_list(ind(j));

    posSet = assoc(assoc(:,1)==diseaseName,2);
    
    s = RandStream.create('mt19937ar','seed',5489);
    RandStream.setDefaultStream(s);

    x=exist([resultpathInit,num2str(diseaseName),'ProDiGe1Loo.mat'],'file');
    if x==0
        save([resultpathInit,num2str(diseaseName),'ProDiGe1Loo.mat'],'x')
        disp(['################',num2str(diseaseName),'########################'])
        Data.posSet=posSet;
        clear posSet
        Data.nsplitCvOut=length(Data.posSet);
        % Run the cross-validation and save the results
        cvresult=doublecv(Data); %#ok<NASGU>
        save([resultpathInit,num2str(diseaseName),'ProDiGe1Loo.mat'], 'cvresult')
    end
end
