function  result = analyzeTEMP(cvresult)

% REQUIRED:
%   This functions calls the following functions that must be on the path:
%       rocanalysis.m
%
% USAGE:
%   results = analyzeTEMP(cvresult)
%
% INPUT:
%   - cvresult = an array of structures, each containing:
%               o score : a list of predicted scores
%               o label : a list of +1/-1 labels corresponding to the
%               scores
%     There is one of these structures per fold of cross-validation
%
% OUTPUT:
%   - A structure result with seven components is produced
%     o result.AUC : AUC for each fold
%     o result.meanAuc : average on the folds of the area under the ROC
%     curves
%     o result.sdAuc : standard deviation of the AUC
%     o result.AUP : AUP for each fold
%     o result.meanAup : average on the folds of the area under the
%     precision/recall curves
%     o result.sdAup : standard deviation of the AUP
%     o result.be : break-even point for each fold
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Default behaviour
rocCurveLength = 1000;

r = cell(1, length(cvresult));
be = NaN(1, length(cvresult));
auc = NaN(1, length(cvresult));
aup = NaN(1, length(cvresult));

for ifold=1:length(cvresult)
    if ~isempty(cvresult{ifold})
    lab = cvresult{ifold}.label(:);
    sc = cvresult{ifold}.score(:);
    
    if sum(lab==0) ~= 0
        sc = sc(abs(lab)>0.5);
        lab = lab(abs(lab)>0.5);
    end
    
    % rocanalysis
    r{ifold} = rocanalysis(lab,sc,rocCurveLength);
    auc(ifold) = r{ifold}.auc;
    aup(ifold) = r{ifold}.aup;
    be(ifold)=r{ifold}.be;
    end
end

result.AupBagged = aup;
result.AucBagged = auc;
result.be=be;
result.meanAup = nanmean(aup);
result.sdAup = nanstd(aup);
result.meanAuc = nanmean(auc);
result.sdAuc = nanstd(auc);
